@@ -1,23 +1,23 @@
-## ----demo, eval=FALSE----------------------------------------------------
+## ----demo, eval=FALSE---------------------------------------------------------
 #  library(googleVis)
 #  demo(googleVis)
 
-## ----setOptions, message=FALSE, echo=FALSE-------------------------------
+## ----setOptions, message=FALSE, echo=FALSE------------------------------------
 library(googleVis)
 library(knitr)
 op <- options(gvis.plot.tag='chart')
 read_demo('googleVis', 'googleVis')
 
-## ----testData, tidy=FALSE------------------------------------------------
+## ----testData, tidy=FALSE-----------------------------------------------------
 df=data.frame(country=c("US", "GB", "BR"), 
               val1=c(10,13,14), 
               val2=c(23,12,32))
 
-## ----LineChart, results='asis', tidy=FALSE-------------------------------
+## ----LineChart, results='asis', tidy=FALSE------------------------------------
 Line <- gvisLineChart(df)
 plot(Line)
 
-## ----TwoAxis, results='asis', tidy=FALSE---------------------------------
+## ----TwoAxis, results='asis', tidy=FALSE--------------------------------------
 Line2 <- gvisLineChart(df, "country", c("val1","val2"),
                        options=list(
                          series="[{targetAxisIndex: 0},
@@ -26,7 +26,85 @@ Line2 <- gvisLineChart(df, "country", c("val1","val2"),
                        ))
 plot(Line2)
 
-## ----SettingOptions, results='asis', tidy=FALSE--------------------------
+## ----BarChart, results='asis', tidy=FALSE-------------------------------------
+Bar <- gvisBarChart(df)
+plot(Bar)
+
+## ----ColumnChart, results='asis', tidy=FALSE----------------------------------
+Column <- gvisColumnChart(df)
+plot(Column)
+
+## ----AreaChart, results='asis', tidy=FALSE------------------------------------
+Area <- gvisAreaChart(df)
+plot(Area)
+
+## ----SteppedAreaChart, results='asis', tidy=FALSE-----------------------------
+SteppedArea <- gvisSteppedAreaChart(df, xvar="country", 
+                                    yvar=c("val1", "val2"),
+                                    options=list(isStacked=TRUE))
+plot(SteppedArea)
+
+## ----ComboChart, results='asis', tidy=FALSE-----------------------------------
+Combo <- gvisComboChart(df, xvar="country",
+                        yvar=c("val1", "val2"),
+                        options=list(seriesType="bars",
+                                     series='{1: {type:"line"}}'))
+plot(Combo)
+
+## ----ScatterChart, results='asis', tidy=FALSE---------------------------------
+Scatter <- gvisScatterChart(women, 
+                            options=list(
+                              legend="none",
+                              lineWidth=2, pointSize=0,
+                              title="Women", vAxis="{title:'weight (lbs)'}",
+                              hAxis="{title:'height (in)'}", 
+                              width=300, height=300))
+plot(Scatter)
+
+## ----BubbleChart, results='asis', tidy=FALSE----------------------------------
+Bubble <- gvisBubbleChart(Fruits, idvar="Fruit", 
+                          xvar="Sales", yvar="Expenses",
+                          colorvar="Year", sizevar="Profit",
+                          options=list(
+                            hAxis='{minValue:75, maxValue:125}'))
+plot(Bubble)
+
+## ----CustomizingLines, results='asis', tidy=FALSE-----------------------------
+Dashed <-  gvisLineChart(df, xvar="country", yvar=c("val1","val2"),
+                        options=list(
+                          series="[{color:'green', targetAxisIndex: 0, 
+                          lineWidth: 1, lineDashStyle: [2, 2, 20, 2, 20, 2]}, 
+                          {color: 'blue',targetAxisIndex: 1, 
+                          lineWidth: 2, lineDashStyle: [4, 1]}]",
+                          vAxes="[{title:'val1'}, {title:'val2'}]"
+                        ))
+plot(Dashed)
+
+## ----ScatterChartPoints, results='asis', tidy=FALSE---------------------------
+M <- matrix(nrow=6,ncol=6)
+M[col(M)==row(M)] <- 1:6
+dat <- data.frame(X=1:6, M)
+SC <- gvisScatterChart(dat, 
+                       options=list(
+                         title="Customizing points",
+                         legend="right",
+                         pointSize=30,
+                         series="{
+                              0: { pointShape: 'circle' },
+                              1: { pointShape: 'triangle' },
+                              2: { pointShape: 'square' },
+                              3: { pointShape: 'diamond' },
+                              4: { pointShape: 'star' },
+                              5: { pointShape: 'polygon' }
+                              }"))
+plot(SC)
+
+## ----EditButton, results='asis', tidy=FALSE-----------------------------------
+Line4 <-  gvisLineChart(df, "country", c("val1","val2"),
+                        options=list(gvis.editor="Edit me!"))
+plot(Line4)
+
+## ----SettingOptions, results='asis', tidy=FALSE-------------------------------
 Line3 <-  gvisLineChart(df, xvar="country", yvar=c("val1","val2"),
                         options=list(
                           title="Hello World",
@@ -46,111 +124,33 @@ Line3 <-  gvisLineChart(df, xvar="country", yvar=c("val1","val2"),
                         ))
 plot(Line3)
 
-## ----CustomizingLines, results='asis', tidy=FALSE------------------------
-Dashed <-  gvisLineChart(df, xvar="country", yvar=c("val1","val2"),
-                        options=list(
-                          series="[{color:'green', targetAxisIndex: 0, 
-                          lineWidth: 1, lineDashStyle: [2, 2, 20, 2, 20, 2]}, 
-                          {color: 'blue',targetAxisIndex: 1, 
-                          lineWidth: 2, lineDashStyle: [4, 1]}]",
-                          vAxes="[{title:'val1'}, {title:'val2'}]"
-                        ))
-plot(Dashed)
-
-## ----EditButton, results='asis', tidy=FALSE------------------------------
-Line4 <-  gvisLineChart(df, "country", c("val1","val2"),
-                        options=list(gvis.editor="Edit me!"))
-plot(Line4)
-
-## ----BarChart, results='asis', tidy=FALSE--------------------------------
-Bar <- gvisBarChart(df)
-plot(Bar)
-
-## ----ColumnChart, results='asis', tidy=FALSE-----------------------------
-Column <- gvisColumnChart(df)
-plot(Column)
-
-## ----AreaChart, results='asis', tidy=FALSE-------------------------------
-Area <- gvisAreaChart(df)
-plot(Area)
-
-## ----SteppedAreaChart, results='asis', tidy=FALSE------------------------
-SteppedArea <- gvisSteppedAreaChart(df, xvar="country", 
-                                    yvar=c("val1", "val2"),
-                                    options=list(isStacked=TRUE))
-plot(SteppedArea)
-
-## ----ComboChart, results='asis', tidy=FALSE------------------------------
-Combo <- gvisComboChart(df, xvar="country",
-                        yvar=c("val1", "val2"),
-                        options=list(seriesType="bars",
-                                     series='{1: {type:"line"}}'))
-plot(Combo)
-
-## ----ScatterChart, results='asis', tidy=FALSE----------------------------
-Scatter <- gvisScatterChart(women, 
-                            options=list(
-                              legend="none",
-                              lineWidth=2, pointSize=0,
-                              title="Women", vAxis="{title:'weight (lbs)'}",
-                              hAxis="{title:'height (in)'}", 
-                              width=300, height=300))
-plot(Scatter)
-
-## ----ScatterChartPoints, results='asis', tidy=FALSE----------------------
-M <- matrix(nrow=6,ncol=6)
-M[col(M)==row(M)] <- 1:6
-dat <- data.frame(X=1:6, M)
-SC <- gvisScatterChart(dat, 
-                       options=list(
-                         title="Customizing points",
-                         legend="right",
-                         pointSize=30,
-                         series="{
-                              0: { pointShape: 'circle' },
-                              1: { pointShape: 'triangle' },
-                              2: { pointShape: 'square' },
-                              3: { pointShape: 'diamond' },
-                              4: { pointShape: 'star' },
-                              5: { pointShape: 'polygon' }
-                              }"))
-plot(SC)
-
-## ----BubbleChart, results='asis', tidy=FALSE-----------------------------
-Bubble <- gvisBubbleChart(Fruits, idvar="Fruit", 
-                          xvar="Sales", yvar="Expenses",
-                          colorvar="Year", sizevar="Profit",
-                          options=list(
-                            hAxis='{minValue:75, maxValue:125}'))
-plot(Bubble)
-
-## ----CandlestickChart, results='asis', tidy=FALSE------------------------
+## ----CandlestickChart, results='asis', tidy=FALSE-----------------------------
 Candle <- gvisCandlestickChart(OpenClose, 
                                options=list(legend='none'))
 plot(Candle)
 
-## ----PieChart, results='asis', tidy=FALSE--------------------------------
+## ----PieChart, results='asis', tidy=FALSE-------------------------------------
 Pie <- gvisPieChart(CityPopularity)
 plot(Pie)
 
-## ----Gauge, results='asis', tidy=FALSE-----------------------------------
+## ----Gauge, results='asis', tidy=FALSE----------------------------------------
 Gauge <-  gvisGauge(CityPopularity, 
                     options=list(min=0, max=800, greenFrom=500,
                                  greenTo=800, yellowFrom=300, yellowTo=500,
                                  redFrom=0, redTo=300, width=400, height=300))
 plot(Gauge)
 
-## ----IntensityMap, results='asis', tidy=FALSE----------------------------
+## ----IntensityMap, results='asis', tidy=FALSE---------------------------------
 Intensity <- gvisIntensityMap(df)
 plot(Intensity)
 
-## ----GeoChart, results='asis', tidy=FALSE--------------------------------
+## ----GeoChart, results='asis', tidy=FALSE-------------------------------------
 Geo=gvisGeoChart(Exports, locationvar="Country", 
                  colorvar="Profit",
                  options=list(projection="kavrayskiy-vii"))
 plot(Geo)
 
-## ----USStateData, results='asis', tidy=FALSE-----------------------------
+## ----USStateData, results='asis', tidy=FALSE----------------------------------
 require(datasets)
 states <- data.frame(state.name, state.x77)
 GeoStates <- gvisGeoChart(states, "state.name", "Illiteracy",
@@ -160,14 +160,14 @@ GeoStates <- gvisGeoChart(states, "state.name", "Illiteracy",
                                        width=600, height=400))
 plot(GeoStates)
 
-## ----GeoChartHurricaneAndrew, results='asis', tidy=FALSE-----------------
+## ----GeoChartHurricaneAndrew, results='asis', tidy=FALSE----------------------
 GeoMarker <- gvisGeoChart(Andrew, "LatLong", 
                           sizevar='Speed_kt',
                           colorvar="Pressure_mb", 
                           options=list(region="US"))
 plot(GeoMarker)
 
-## ----GoogleMapHurricaneAndrew, results='asis', tidy=FALSE----------------
+## ----GoogleMapHurricaneAndrew, results='asis', tidy=FALSE---------------------
 AndrewMap <- gvisMap(Andrew, "LatLong" , "Tip", 
                      options=list(showTip=TRUE, 
                                   showLine=TRUE, 
@@ -176,32 +176,32 @@ AndrewMap <- gvisMap(Andrew, "LatLong" , "Tip",
                                   useMapTypeControl=TRUE))
 plot(AndrewMap)
 
-## ----Table, results='asis', tidy=FALSE-----------------------------------
+## ----Table, results='asis', tidy=FALSE----------------------------------------
 Table <- gvisTable(Stock, 
                    formats=list(Value="#,###"))
 plot(Table)
 
-## ----TableWithPages, results='asis', tidy=FALSE--------------------------
+## ----TableWithPages, results='asis', tidy=FALSE-------------------------------
 PopTable <- gvisTable(Population, 
                       formats=list(Population="#,###",
                                    '% of World Population'='#.#%'),
                       options=list(page='enable'))
 plot(PopTable)
 
-## ----OrgChart, results='asis', tidy=FALSE--------------------------------
+## ----OrgChart, results='asis', tidy=FALSE-------------------------------------
 Org <- gvisOrgChart(Regions, 
                     options=list(width=600, height=250,
                                  size='large', allowCollapse=TRUE))
 plot(Org)
 
-## ----TreeMap, results='asis', tidy=FALSE---------------------------------
+## ----TreeMap, results='asis', tidy=FALSE--------------------------------------
 Tree <- gvisTreeMap(Regions,  
                     "Region", "Parent", 
                     "Val", "Fac", 
                     options=list(fontSize=16))
 plot(Tree)
 
-## ----AnnotationChart, results='asis', tidy=FALSE-------------------------
+## ----AnnotationChart, results='asis', tidy=FALSE------------------------------
 Anno <- gvisAnnotationChart(Stock, 
                             datevar="Date",
                             numvar="Value", 
@@ -215,7 +215,7 @@ Anno <- gvisAnnotationChart(Stock,
 )
 plot(Anno)
 
-## ----SankeyChart, results='asis', tidy=FALSE-----------------------------
+## ----SankeyChart, results='asis', tidy=FALSE----------------------------------
 datSK <- data.frame(From=c(rep("A",3), rep("B", 3)),
                     To=c(rep(c("X", "Y", "Z"),2)),
                     Weight=c(5,7,6,2,9,4))
@@ -227,7 +227,7 @@ Sankey <- gvisSankey(datSK, from="From", to="To", weight="Weight",
                             label: { color: '#871b47' } }}"))
 plot(Sankey)
 
-## ----Histogram, results='asis', tidy=FALSE-------------------------------
+## ----Histogram, results='asis', tidy=FALSE------------------------------------
 set.seed(123)
 datHist=data.frame(A=rpois(100, 20),
                    B=rpois(100, 5),
@@ -239,7 +239,7 @@ Hist <- gvisHistogram(datHist, options=list(
   width=400, height=360))
 plot(Hist)
 
-## ----CalendarChart, results='asis', tidy=FALSE---------------------------
+## ----CalendarChart, results='asis', tidy=FALSE--------------------------------
 Cal <- gvisCalendar(Cairo, 
                     datevar="Date", 
                     numvar="Temp",
@@ -254,7 +254,7 @@ Cal <- gvisCalendar(Cairo,
 )
 plot(Cal)
 
-## ----Timeline, results='asis', tidy=FALSE--------------------------------
+## ----Timeline, results='asis', tidy=FALSE-------------------------------------
 datTL <- data.frame(Position=c(rep("President", 3), rep("Vice", 3)),
                     Name=c("Washington", "Adams", "Jefferson",
                            "Adams", "Jefferson", "Burr"),
@@ -274,7 +274,11 @@ Timeline <- gvisTimeline(data=datTL,
                                       colors="['#cbb69d', '#603913', '#c69c6e']"))
 plot(Timeline)
 
-## ----gvisMerge, results='asis', tidy=FALSE-------------------------------
+## ----WordTree, results='asis', tidy=FALSE-------------------------------------
+wt1 <- gvisWordTree(Cats, textvar = "Phrase")
+plot(wt1)
+
+## ----gvisMerge, results='asis', tidy=FALSE------------------------------------
 G <- gvisGeoChart(Exports, "Country", "Profit", 
                   options=list(width=300, height=300))
 T <- gvisTable(Exports, 
@@ -283,13 +287,13 @@ T <- gvisTable(Exports,
 GT <- gvisMerge(G,T, horizontal=TRUE) 
 plot(GT)
 
-## ----MotionChart, results='asis', tidy=FALSE-----------------------------
+## ----MotionChart, results='asis', tidy=FALSE----------------------------------
 Motion=gvisMotionChart(Fruits, 
                        idvar="Fruit", 
                        timevar="Year")
 plot(Motion)
 
-## ----MotionChartSettings, results='asis', tidy=FALSE---------------------
+## ----MotionChartSettings, results='asis', tidy=FALSE--------------------------
 myStateSettings <-'
 {"xZoomedDataMin":1199145600000,"colorOption":"2",
 "duration":{"timeUnit":"Y","multiplier":1},"yLambda":1,
@@ -308,7 +312,7 @@ plot(M)
 
 ## See demo(package='googleVis') for other available demos.
 
-## ----GeoMap, results='asis', tidy=FALSE----------------------------------
+## ----GeoMap, results='asis', tidy=FALSE---------------------------------------
 AndrewGeo <- gvisGeoMap(Andrew, 
                         locationvar="LatLong", 
                         numvar="Speed_kt", 
@@ -318,7 +322,7 @@ AndrewGeo <- gvisGeoMap(Andrew,
                                      dataMode="markers"))
 plot(AndrewGeo)
 
-## ----AnnotatedTimeLine, results='asis', tidy=FALSE-----------------------
+## ----AnnotatedTimeLine, results='asis', tidy=FALSE----------------------------
 AnnoTimeLine  <- gvisAnnotatedTimeLine(Stock, 
                                        datevar="Date",
                                        numvar="Value", 
